﻿using Rhino;
using Rhino.Commands;
using Rhino.Geometry;
using Rhino.Input.Custom;

namespace TransformSubObj
{
    public class TransformSubObjCommand : Command
    {
        public TransformSubObjCommand()
        {
            Instance = this;
        }
        public static TransformSubObjCommand Instance
        {
            get; private set;
        }
        public override string EnglishName => "TransformSubObj";
        protected override Result RunCommand(RhinoDoc doc, RunMode mode)
        {
            var go = new GetObject {GeometryFilter = Rhino.DocObjects.ObjectType.Surface, SubObjectSelect = true};
            go.SetCommandPrompt("Select brep-face to transform");
            go.Get();
            if (go.CommandResult() != Result.Success) return go.CommandResult();
            var objref = go.Object(0);
            var brep = objref.Brep();
            var xform = Transform.Scale(Plane.WorldXY, 1.2, 1.2, 1.2);
            brep.TransformComponent(new []{objref.GeometryComponentIndex},xform, doc.ModelAbsoluteTolerance, 0, true);
            doc.Objects.Replace(objref.ObjectId, brep);
            doc.Views.Redraw();
            return Result.Success;
        }
    }
}